/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.artifacts;

import org.eclipse.cosmos.rm.validation.internal.reference.XPointerExpression;

/**
 * An element edge represents an edge from a target to a source
 * element from/in the contained document
 * 
 * @author Ali Mehregani
 */
public class ElementEdge
{
	/**
	 * The reference string that will be used to resolve the target 
	 * document and element.
	 */
	private String reference;

	/**
	 * The source element
	 */
	private String srcReferenceType;

	/**
	 * The XPointer expression
	 */
	private XPointerExpression xpointerExpression;
	
	
	/**
	 * Constructor
	 */
	public ElementEdge(String srcReferenceType)
	{
		reference = "";
		this.srcReferenceType = srcReferenceType;
	}
	
	
	/**
	 * Set the source element
	 * 
	 * @param sourceElement The source element
	 */
	public void setSrcReferenceType(String sourceElement)
	{
		this.srcReferenceType = sourceElement;
	}

	
	/**
	 * Returns the source element
	 * 
	 * @return source element
	 */
	public String getSrcReferenceType()
	{
		return srcReferenceType;
	}
	
	
	/**
	 * Appends to the reference path
	 * 
	 * @param referece the string to be appended to the reference path
	 */
	public void appendToReference(String referece)
	{
		this.reference += referece;		
	}
	
	
	/**
	 * Returns the reference string
	 * 
	 * @return The reference string
	 */
	public String getReference()
	{
		return reference;
	}

	
	/**
	 * Sets the reference string
	 * 
	 * @param reference The reference string
	 */
	public void setReference(String reference)
	{
		this.reference = reference;
	}


	/**
	 * Returns the document that this edge orginates from
	 * 
	 * @return The alias of the document that this edge orginates
	 * from.
	 */
	public String getDocument()
	{
		if (xpointerExpression == null)
			xpointerExpression = new XPointerExpression(reference);
		
		return xpointerExpression.getDocumentAlias();
	}
}
